==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/sw.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Huwezi kuondoa ruhusa yako ya kusoma.",
    "Team folders" : "Folda za timu",
    "Admin configured folders shared with everyone in a team" : "Msimamizi alisanidi folda zinazoshirikiwa na kila mtu katika timu",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Msimamizi aliyesanidi folda zinazoshirikiwa na kila mtu katika timu.\n\nFolda zinaweza kusanidiwa kutoka kwa *Folda za Timu* katika mipangilio ya msimamizi.\n\nBaada ya folda kuunda, msimamizi anaweza kutoa idhini ya kufikia folda kwa timu moja au zaidi, kudhibiti ruhusa zao za kuandika/kushiriki na kugawa sehemu ya folda.\nKuanzia Hub 10/Nextcloud 31, msimamizi anahitaji kuwa sehemu ya timu ili aweze kuikabidhi Timu.",
    "Unset" : "Haijawekwa",
    "Denied (Inherited permission)" : "Imekataliwa (Ruhusa ya kurithi)",
    "Allowed (Inherited permission)" : "Imeruhusiwa (Ruhusa ya kurithi)",
    "Denied" : "Imekataliwa",
    "Allowed" : "Inaruhusiwa",
    "Access denied" : "Ufikiaji umekataliwa",
    "Access allowed" : "Ufikiaji unaruhusiwa",
    "Inherit permission" : "Rithi ruhusa",
    "Deny" : "Kataa",
    "Allow" : "Ruhusu",
    "Group" : "Kundi",
    "Team" : "Timu",
    "Team folder" : "Folda ya timu",
    "Read" : "Soma",
    "Write" : "Andika",
    "Create" : "Tengeneza",
    "Delete" : "Futa",
    "Share" : "Shirikisha",
    "You" : "Wewe",
    "Remove access rule" : "Ondoa sheria ya ufikiaji",
    "Add advanced permission rule" : "Ongeza sheria ya juu ya ruhusa",
    "Select a user or group" : "Chagua mtumiaji au kikundi",
    "Open Team folder" : "Fungua folda ya Timu",
    "Permission denied. User does not have sufficient permissions." : "Ruhusa imekataliwa. Mtumiaji hana ruhusa za kutosha.",
    "Unexpected status from server" : "Hali isiyotarajiwa kutoka kwa seva",
    "List of Team folders." : "Orodha ya folda za Timu.",
    "No Team folders yet" : "Bado hakuna folda za Timu",
    "Team folders will show up here" : "Folda za timu zitaonekana hapa",
    "Add group" : "Ongeza kundi",
    "Default" : "Chaguo msingi",
    "Unlimited" : "Isiyo na kikomo",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Je, una uhakika unataka kufuta \"{folderName}\" na faili zote ndani? Operesheni hii haiwezi kutenduliwa",
    "Delete \"{folderName}\"?" : "Futa \"{folderName}\"?",
    "Team folder admin delegation" : "Uteuzi wa msimamizi wa folda ya timu",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud inakuruhusu kukabidhi usimamizi wa folda za Timu kwa watumiaji wasio wasimamizi.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Bainisha hapa chini vikundi ambavyo vitaruhusiwa kudhibiti folda za Timu na kutumia API/REST yake.",
    "They will have access to all Team folders." : "Wataweza kufikia folda zote za Timu.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Bainisha hapa chini vikundi ambavyo vitaruhusiwa kudhibiti folda za Timu na kutumia API/REST yake pekee.",
    "They will only have access to Team folders for which they have advanced permissions." : "Watakuwa na idhini ya kufikia folda za Timu pekee ambazo wana ruhusa za juu zaidi.",
    "Group or team" : "Kundi au timu",
    "Sort by number of groups or teams that have access to this folder" : "Panga kwa idadi ya vikundi au timu ambazo zinaweza kufikia folda hii",
    "Sort by number of groups that have access to this folder" : "Panga kwa idadi ya vikundi vinavyoweza kufikia folda hii",
    "Folder name" : "Jina la kisanduku",
    "Quota" : "Kiasi",
    "Advanced Permissions" : "Ruhusa za Juu",
    "Pagination of team folders" : "Pagination ya folda za timu",
    "Previous" : "Iliyopita",
    "Next" : "Inayofuata",
    "User" : "Mtumiaji",
    "Unknown" : "Haijulikani",
    "Users/groups that can manage" : "Watumiaji/vikundi vinavyoweza kudhibiti",
    "None" : "Hakuna",
    "No other groups or teams available" : "Hakuna vikundi au timu zingine zinazopatikana",
    "No other groups available" : "Hakuna vikundi vingine vinavyopatikana",
    "{displayName} (team)" : "{displayName} (timu)",
    "Add group or team" : "Ongeza kikundi au timu",
    "{size} used" : "{size}imetumika",
    "Other …" : "Other …",
    "You can not remove your own read permission." : "You can not remove your own read permission.",
    "Group folders" : "Folda za kundi",
    "Admin configured folders shared with everyone in a group" : "Folda zilizosanidiwa za msimamizi zinazoshirikiwa na kila mtu katika kikundi",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Folda zilizosanidiwa za msimamizi zinazoshirikiwa na kila mtu katika kikundi.\n\nFolda zinaweza kusanidiwa kutoka kwa *Folda za Kikundi* katika mipangilio ya msimamizi.\n\nBaada ya folda kuunda, msimamizi anaweza kutoa ufikiaji wa folda kwa kikundi kimoja au zaidi, kudhibiti ruhusa zao za kuandika/kushiriki na kugawa sehemu ya folda.",
    "Group folder" : "Folda ya kikundi",
    "Open group folder" : "Fungua folda ya kikundi",
    "List of group folders." : "Orodha ya folda za kikundi.",
    "No group folders yet" : "Bado hakuna folda za kikundi",
    "Group folders will show up here" : "Folda za kikundi zitaonekana hapa",
    "Group folder admin delegation" : "Uteuzi wa msimamizi wa folda ya kikundi",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud inakuruhusu kukabidhi usimamizi wa folda za kikundi kwa watumiaji wasio wasimamizi.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Bainisha hapa chini vikundi ambavyo vitaruhusiwa kudhibiti folda za kikundi na kutumia API/REST yake.",
    "They will have access to all group folders." : "Watapata ufikiaji wa folda zote za kikundi.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Bainisha hapa chini vikundi ambavyo vitaruhusiwa kudhibiti folda za kikundi na kutumia API/REST yake pekee.",
    "They will only have access to group folders for which they have advanced permissions." : "Wataweza tu kufikia folda za kikundi ambazo wana ruhusa za juu zaidi.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Msimamizi aliyesanidi folda zinazoshirikiwa na kila mtu katika timu.\n\nFolda zinaweza kusanidiwa kutoka kwa *Folda za Timu* katika mipangilio ya msimamizi.\n\nBaada ya folda kuunda, msimamizi anaweza kutoa idhini ya kufikia folda kwa timu moja au zaidi, kudhibiti ruhusa zao za kuandika/kushiriki na kugawa sehemu ya folda."
},
"nplurals=2; plural=(n != 1);");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/sw.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Huwezi kuondoa ruhusa yako ya kusoma.",
    "Team folders" : "Folda za timu",
    "Unset" : "Haijawekwa",
    "Denied (Inherited permission)" : "Imekataliwa (Ruhusa ya kurithi)",
    "Allowed (Inherited permission)" : "Imeruhusiwa (Ruhusa ya kurithi)",
    "Denied" : "Imekataliwa",
    "Allowed" : "Inaruhusiwa",
    "Access denied" : "Ufikiaji umekataliwa",
    "Access allowed" : "Ufikiaji unaruhusiwa",
    "Inherit permission" : "Rithi ruhusa",
    "Deny" : "Kataa",
    "Allow" : "Ruhusu",
    "Group" : "Kundi",
    "Team" : "Timu",
    "Team folder" : "Folda ya timu",
    "Read" : "Soma",
    "Write" : "Andika",
    "Create" : "Tengeneza",
    "Delete" : "Futa",
    "Share" : "Shirikisha",
    "You" : "Wewe",
    "Remove access rule" : "Ondoa sheria ya ufikiaji",
    "Add advanced permission rule" : "Ongeza sheria ya juu ya ruhusa",
    "Select a user or group" : "Chagua mtumiaji au kikundi",
    "Open Team folder" : "Fungua folda ya Timu",
    "Permission denied. User does not have sufficient permissions." : "Ruhusa imekataliwa. Mtumiaji hana ruhusa za kutosha.",
    "Unexpected status from server" : "Hali isiyotarajiwa kutoka kwa seva",
    "List of Team folders." : "Orodha ya folda za Timu.",
    "No Team folders yet" : "Bado hakuna folda za Timu",
    "Team folders will show up here" : "Folda za timu zitaonekana hapa",
    "Add group" : "Ongeza kundi",
    "Default" : "Chaguo msingi",
    "Unlimited" : "Isiyo na kikomo",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Je, una uhakika unataka kufuta \"{folderName}\" na faili zote ndani? Operesheni hii haiwezi kutenduliwa",
    "Delete \"{folderName}\"?" : "Futa \"{folderName}\"?",
    "Team folder admin delegation" : "Uteuzi wa msimamizi wa folda ya timu",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud inakuruhusu kukabidhi usimamizi wa folda za Timu kwa watumiaji wasio wasimamizi.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Bainisha hapa chini vikundi ambavyo vitaruhusiwa kudhibiti folda za Timu na kutumia API/REST yake.",
    "They will have access to all Team folders." : "Wataweza kufikia folda zote za Timu.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Bainisha hapa chini vikundi ambavyo vitaruhusiwa kudhibiti folda za Timu na kutumia API/REST yake pekee.",
    "They will only have access to Team folders for which they have advanced permissions." : "Watakuwa na idhini ya kufikia folda za Timu pekee ambazo wana ruhusa za juu zaidi.",
    "Group or team" : "Kundi au timu",
    "Sort by number of groups or teams that have access to this folder" : "Panga kwa idadi ya vikundi au timu ambazo zinaweza kufikia folda hii",
    "Sort by number of groups that have access to this folder" : "Panga kwa idadi ya vikundi vinavyoweza kufikia folda hii",
    "Folder name" : "Jina la kisanduku",
    "Quota" : "Kiasi",
    "Advanced Permissions" : "Ruhusa za Juu",
    "Pagination of team folders" : "Pagination ya folda za timu",
    "Previous" : "Iliyopita",
    "Next" : "Inayofuata",
    "User" : "Mtumiaji",
    "Unknown" : "Haijulikani",
    "Users/groups that can manage" : "Watumiaji/vikundi vinavyoweza kudhibiti",
    "None" : "Hakuna",
    "No other groups or teams available" : "Hakuna vikundi au timu zingine zinazopatikana",
    "No other groups available" : "Hakuna vikundi vingine vinavyopatikana",
    "{displayName} (team)" : "{displayName} (timu)",
    "Add group or team" : "Ongeza kikundi au timu",
    "{size} used" : "{size}imetumika",
    "Other …" : "Other …",
    "You can not remove your own read permission." : "You can not remove your own read permission.",
    "Group folders" : "Folda za kundi",
    "Admin configured folders shared with everyone in a group" : "Folda zilizosanidiwa za msimamizi zinazoshirikiwa na kila mtu katika kikundi",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Folda zilizosanidiwa za msimamizi zinazoshirikiwa na kila mtu katika kikundi.\n\nFolda zinaweza kusanidiwa kutoka kwa *Folda za Kikundi* katika mipangilio ya msimamizi.\n\nBaada ya folda kuunda, msimamizi anaweza kutoa ufikiaji wa folda kwa kikundi kimoja au zaidi, kudhibiti ruhusa zao za kuandika/kushiriki na kugawa sehemu ya folda.",
    "Group folder" : "Folda ya kikundi",
    "Open group folder" : "Fungua folda ya kikundi",
    "List of group folders." : "Orodha ya folda za kikundi.",
    "No group folders yet" : "Bado hakuna folda za kikundi",
    "Group folders will show up here" : "Folda za kikundi zitaonekana hapa",
    "Group folder admin delegation" : "Uteuzi wa msimamizi wa folda ya kikundi",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud inakuruhusu kukabidhi usimamizi wa folda za kikundi kwa watumiaji wasio wasimamizi.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Bainisha hapa chini vikundi ambavyo vitaruhusiwa kudhibiti folda za kikundi na kutumia API/REST yake.",
    "They will have access to all group folders." : "Watapata ufikiaji wa folda zote za kikundi.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Bainisha hapa chini vikundi ambavyo vitaruhusiwa kudhibiti folda za kikundi na kutumia API/REST yake pekee.",
    "They will only have access to group folders for which they have advanced permissions." : "Wataweza tu kufikia folda za kikundi ambazo wana ruhusa za juu zaidi.",
    "Admin configured folders shared with everyone in a team" : "Msimamizi alisanidi folda zinazoshirikiwa na kila mtu katika timu",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Msimamizi aliyesanidi folda zinazoshirikiwa na kila mtu katika timu.\n\nFolda zinaweza kusanidiwa kutoka kwa *Folda za Timu* katika mipangilio ya msimamizi.\n\nBaada ya folda kuunda, msimamizi anaweza kutoa idhini ya kufikia folda kwa timu moja au zaidi, kudhibiti ruhusa zao za kuandika/kushiriki na kugawa sehemu ya folda.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Msimamizi aliyesanidi folda zinazoshirikiwa na kila mtu katika timu.\n\nFolda zinaweza kusanidiwa kutoka kwa *Folda za Timu* katika mipangilio ya msimamizi.\n\nBaada ya folda kuunda, msimamizi anaweza kutoa idhini ya kufikia folda kwa timu moja au zaidi, kudhibiti ruhusa zao za kuandika/kushiriki na kugawa sehemu ya folda.\nKuanzia Hub 10/Nextcloud 31, msimamizi anahitaji kuwa sehemu ya timu ili aweze kuikabidhi Timu."
},
"nplurals=2; plural=(n != 1);");
